@@ -60,10 +60,14 @@ byComplexity <- function(x, model)
            {
              x[order(x$size, -x$decay),]
            },
-           knn =, lvq =, multinom =
+           knn =, multinom =
            {
              x[order(-x[,1]),]
            },
+           lvq =
+           {
+             x[order(-x$k, -x$size),]
+           },
            mars =, earth =, fda =, bagEarth =, bagFDA =
            {
              x[order(x$degree, x$nprune),]
